# ASIMOV Software Development Kit (SDK) for Python

[![License](https://img.shields.io/badge/license-Public%20Domain-blue.svg)](https://unlicense.org)
[![Compatibility](https://img.shields.io/badge/python-3.9%2B-blue)](https://endoflife.date/python)
[![Package](https://img.shields.io/pypi/v/asimov.py)](https://pypi.org/project/asimov.py/)

**[ASIMOV] is a polyglot development platform for
[trustworthy neurosymbolic machine intelligence].**

<br/>

<sub>

[[Features](#-features)] |
[[Prerequisites](#%EF%B8%8F-prerequisites)] |
[[Installation](#%EF%B8%8F-installation)] |
[[Examples](#-examples)] |
[[Reference](#-reference)] |
[[Development](#%E2%80%8D-development)]

</sub>

## ✨ Features

- Defines [flow-based] [program patterns] for refining data into knowledge.
- Implements a [module system] enabling an ecosystem of [modules].
- Enables dataflow systems through reusable components called blocks.
- Supports opting out of any feature using comprehensive feature flags.
- Adheres to the Rust API Guidelines in its [naming conventions].
- Cuts red tape: 100% free and unencumbered public domain software.

## 🛠️ Prerequisites

- [Python](https://python.org) 3.9+ (included in macOS 12.6+)

## ⬇️ Installation

### Installation via PyPI

```bash
pip install asimov.py
```

## 👉 Examples

### Importing the SDK

```python
from asimov import *
```

## 📚 Reference

## 👨‍💻 Development

```bash
git clone https://github.com/asimov-platform/asimov.py.git
```

---

[![Share on X](https://img.shields.io/badge/share%20on-x-03A9F4?logo=x)](https://x.com/intent/post?url=https://github.com/asimov-platform/asimov.py&text=ASIMOV%20Software%20Development%20Kit%20%28SDK%29%20for%20Python)
[![Share on Reddit](https://img.shields.io/badge/share%20on-reddit-red?logo=reddit)](https://reddit.com/submit?url=https://github.com/asimov-platform/asimov.py&title=ASIMOV%20Software%20Development%20Kit%20%28SDK%29%20for%20Python)
[![Share on Hacker News](https://img.shields.io/badge/share%20on-hn-orange?logo=ycombinator)](https://news.ycombinator.com/submitlink?u=https://github.com/asimov-platform/asimov.py&t=ASIMOV%20Software%20Development%20Kit%20%28SDK%29%20for%20Python)
[![Share on Facebook](https://img.shields.io/badge/share%20on-fb-1976D2?logo=facebook)](https://www.facebook.com/sharer/sharer.php?u=https://github.com/asimov-platform/asimov.py)
[![Share on LinkedIn](https://img.shields.io/badge/share%20on-linkedin-3949AB?logo=linkedin)](https://www.linkedin.com/sharing/share-offsite/?url=https://github.com/asimov-platform/asimov.py)

[ASIMOV]: https://asimov.sh
[ASIMOV.py]: https://github.com/asimov-platform/asimov.py
[flow-based]: https://github.com/artob/awesome-fbp
[modules]: https://github.com/asimov-modules
[module system]: https://asimov-specs.github.io
[program patterns]: https://asimov-specs.github.io/program-patterns/
[trustworthy neurosymbolic machine intelligence]: https://asimov.blog/introducing-asimov/
